==> mx-image-loader-0.0.1-sources.jar: com/mxchip/image_loader/ImageLoaderByEmpty.java <==
package com.mxchip.image_loader;

import android.app.Activity;
import android.content.Context;
import android.util.Log;
import android.widget.ImageView;

import com.mxchip.config.DisplayConfig;
import com.mxchip.interfaces.IImageLoader;

import java.io.File;

/**
 * Created with Android Studio
 *
 * @author: chenxukun
 * @date: 2020/8/19
 * @time: 7:31 PM
 * @desc:
 */
public class ImageLoaderByEmpty implements IImageLoader {
    @Override
    public void display(ImageView imageView, String url) {
        emptyEngine();
    }

    @Override
    public void display(ImageView imageView, String url, int radius) {
        emptyEngine();
    }

    @Override
    public void display(ImageView imageView, String url, int radius, int direction) {
        emptyEngine();
    }

    @Override
    public void display(ImageView imageView, String url, DisplayConfig op) {
        emptyEngine();
    }

    @Override
    public void display(Activity activity, ImageView imageView, String url) {
        emptyEngine();
    }

    @Override
    public void display(Activity activity, ImageView imageView, String url, DisplayConfig op) {
        emptyEngine();
    }

    @Override
    public void display(Activity activity, ImageView imageView, String url, int radius) {
        emptyEngine();
    }

    @Override
    public void display(Activity activity, ImageView imageView, String url, int radius, int direction) {
        emptyEngine();
    }

    @Override
    public void display(ImageView imageView, int resId) {
        emptyEngine();
    }

    @Override
    public void display(ImageView imageView, int resId, int radius) {
        emptyEngine();
    }

    @Override
    public void display(ImageView imageView, int resId, int radius, int direction) {
        emptyEngine();
    }

    @Override
    public void display(ImageView imageView, int resId, DisplayConfig op) {
        emptyEngine();
    }

    @Override
    public void display(Activity activity, ImageView imageView, int resId) {
        emptyEngine();
    }

    @Override
    public void display(Activity activity, ImageView imageView, int resId, DisplayConfig op) {
        emptyEngine();
    }

    @Override
    public void display(Activity activity, ImageView imageView, int resId, int radius) {
        emptyEngine();
    }

    @Override
    public void display(Activity activity, ImageView imageView, int resId, int radius, int direction) {
        emptyEngine();
    }

    @Override
    public void display(ImageView imageView, File file) {
        emptyEngine();
    }

    @Override
    public void display(ImageView imageView, File file, DisplayConfig op) {
        emptyEngine();
    }

    @Override
    public void display(ImageView imageView, File file, int radius) {
        emptyEngine();
    }

    @Override
    public void display(ImageView imageView, File file, int radius, int direction) {
        emptyEngine();
    }

    @Override
    public void display(Activity activity, ImageView imageView, File file) {
        emptyEngine();
    }

    @Override
    public void display(Activity activity, ImageView imageView, File file, DisplayConfig op) {
        emptyEngine();
    }

    @Override
    public void display(Activity activity, ImageView imageView, File file, int radius) {
        emptyEngine();
    }

    @Override
    public void display(Activity activity, ImageView imageView, File file, int radius, int direction) {
        emptyEngine();
    }

    @Override
    public void startGif(ImageView imageView) {
        emptyEngine();
    }

    @Override
    public void stopGif(ImageView imageView) {
        emptyEngine();
    }

    @Override
    public void recycleGif(ImageView imageView) {
        emptyEngine();
    }

    @Override
    public void cancel(ImageView imageView) {
        emptyEngine();
    }

    @Override
    public void pauseRequest() {
        emptyEngine();
    }

    @Override
    public void resumeRequest() {
        emptyEngine();
    }

    @Override
    public void clearMemoryCache() {
        emptyEngine();
    }

    @Override
    public void clearDiskCache() {
        emptyEngine();
    }

    @Override
    public void onTrimMemory(int level) {
        emptyEngine();
    }

    @Override
    public void onLowMemory() {
        emptyEngine();
    }

    @Override
    public void init(Context context) {
        emptyEngine();
    }

    @Override
    public void release() {
        emptyEngine();
    }

    private void emptyEngine() {
        Log.i("ImageLoader", "=====================================================");
        Log.i("ImageLoader", "| there is no imageloader engine, cannot load image |");
        Log.i("ImageLoader", "=====================================================");
    }
}

==> mx-image-loader-0.0.2-sources.jar: com/mxchip/image_loader/ImageLoaderByEmpty.java <==
package com.mxchip.image_loader;

import android.app.Activity;
import android.content.Context;
import android.util.Log;
import android.widget.ImageView;

import com.mxchip.config.DisplayConfig;
import com.mxchip.interfaces.IImageLoader;

import java.io.File;

/**
 * Created with Android Studio
 *
 * @author: chenxukun
 * @date: 2020/8/19
 * @time: 7:31 PM
 * @desc:
 */
public class ImageLoaderByEmpty implements IImageLoader {
    @Override
    public void display(ImageView imageView, String url) {
        emptyEngine();
    }

    @Override
    public void display(ImageView imageView, String url, int radius) {
        emptyEngine();
    }

    @Override
    public void display(ImageView imageView, String url, int radius, int direction) {
        emptyEngine();
    }

    @Override
    public void display(ImageView imageView, String url, DisplayConfig op) {
        emptyEngine();
    }

    @Override
    public void display(Activity activity, ImageView imageView, String url) {
        emptyEngine();
    }

    @Override
    public void display(Activity activity, ImageView imageView, String url, DisplayConfig op) {
        emptyEngine();
    }

    @Override
    public void display(Activity activity, ImageView imageView, String url, int radius) {
        emptyEngine();
    }

    @Override
    public void display(Activity activity, ImageView imageView, String url, int radius, int direction) {
        emptyEngine();
    }

    @Override
    public void display(Context context, ImageView imageView, String url) {
        emptyEngine();
    }

    @Override
    public void display(Context context, ImageView imageView, String url, DisplayConfig config) {
        emptyEngine();
    }

    @Override
    public void display(Context context, ImageView imageView, String url, int radius) {
        emptyEngine();
    }

    @Override
    public void display(Context context, ImageView imageView, String url, int radius, int direction) {
        emptyEngine();
    }

    @Override
    public void display(ImageView imageView, int resId) {
        emptyEngine();
    }

    @Override
    public void display(ImageView imageView, int resId, int radius) {
        emptyEngine();
    }

    @Override
    public void display(ImageView imageView, int resId, int radius, int direction) {
        emptyEngine();
    }

    @Override
    public void display(ImageView imageView, int resId, DisplayConfig op) {
        emptyEngine();
    }

    @Override
    public void display(Activity activity, ImageView imageView, int resId) {
        emptyEngine();
    }

    @Override
    public void display(Activity activity, ImageView imageView, int resId, DisplayConfig op) {
        emptyEngine();
    }

    @Override
    public void display(Activity activity, ImageView imageView, int resId, int radius) {
        emptyEngine();
    }

    @Override
    public void display(Activity activity, ImageView imageView, int resId, int radius, int direction) {
        emptyEngine();
    }

    @Override
    public void display(Context context, ImageView imageView, int resId) {
        emptyEngine();
    }

    @Override
    public void display(Context context, ImageView imageView, int resId, DisplayConfig op) {
        emptyEngine();
    }

    @Override
    public void display(Context context, ImageView imageView, int resId, int radius) {
        emptyEngine();
    }

    @Override
    public void display(Context context, ImageView imageView, int resId, int radius, int direction) {
        emptyEngine();
    }

    @Override
    public void display(ImageView imageView, File file) {
        emptyEngine();
    }

    @Override
    public void display(ImageView imageView, File file, DisplayConfig op) {
        emptyEngine();
    }

    @Override
    public void display(ImageView imageView, File file, int radius) {
        emptyEngine();
    }

    @Override
    public void display(ImageView imageView, File file, int radius, int direction) {
        emptyEngine();
    }

    @Override
    public void display(Activity activity, ImageView imageView, File file) {
        emptyEngine();
    }

    @Override
    public void display(Activity activity, ImageView imageView, File file, DisplayConfig op) {
        emptyEngine();
    }

    @Override
    public void display(Activity activity, ImageView imageView, File file, int radius) {
        emptyEngine();
    }

    @Override
    public void display(Activity activity, ImageView imageView, File file, int radius, int direction) {
        emptyEngine();
    }

    @Override
    public void display(Context context, ImageView imageView, File file) {
        emptyEngine();
    }

    @Override
    public void display(Context context, ImageView imageView, File file, DisplayConfig op) {
        emptyEngine();
    }

    @Override
    public void display(Context context, ImageView imageView, File file, int radius) {
        emptyEngine();
    }

    @Override
    public void display(Context context, ImageView imageView, File file, int radius, int direction) {
        emptyEngine();
    }

    @Override
    public void startGif(ImageView imageView) {
        emptyEngine();
    }

    @Override
    public void stopGif(ImageView imageView) {
        emptyEngine();
    }

    @Override
    public void recycleGif(ImageView imageView) {
        emptyEngine();
    }

    @Override
    public void cancel(ImageView imageView) {
        emptyEngine();
    }

    @Override
    public void pauseRequest() {
        emptyEngine();
    }

    @Override
    public void resumeRequest() {
        emptyEngine();
    }

    @Override
    public void clearMemoryCache() {
        emptyEngine();
    }

    @Override
    public void clearDiskCache() {
        emptyEngine();
    }

    @Override
    public void onTrimMemory(int level) {
        emptyEngine();
    }

    @Override
    public void onLowMemory() {
        emptyEngine();
    }

    @Override
    public void init(Context context) {
        emptyEngine();
    }

    @Override
    public void release() {
        emptyEngine();
    }

    private void emptyEngine() {
        Log.i("ImageLoader", "=====================================================");
        Log.i("ImageLoader", "| there is no imageloader engine, cannot load image |");
        Log.i("ImageLoader", "=====================================================");
    }
}
